pub struct Config {
pub max_width: Option<usize>,
pub fixed_zero_padding: Option<usize>,
pub fixed_number: Option<usize>,
pub fixed_ordered_list_marker: Option<OrderedListMarker>,
pub fixed_unordered_list_marker: Option<UnorderedListMarker>,
pub fixed_indentation: Option<Cow<'static, str>>,
}Expand description
Configuration options for the Markdown formatter.
Fields
max_width: Option<usize>Maximum line width.
fixed_zero_padding: Option<usize>If set, all ordered lists will have this many leading zeroes.
fixed_number: Option<usize>If set, all ordered lists will begin with this number.
fixed_ordered_list_marker: Option<OrderedListMarker>If set, all ordered lists will have this marker after the number.
fixed_unordered_list_marker: Option<UnorderedListMarker>If set, all unordered lists will begin with this marker.
fixed_indentation: Option<Cow<'static, str>>If set, all lists will have this many indentation per level.
Implementations
Sourceimpl Config
impl Config
Sourcepub fn sichanghe_opinion() -> Self
pub fn sichanghe_opinion() -> Self
Steven Hé (Sīchàng)’s opinion on the style.
Sourcepub fn list_marker(
&self,
source: &str,
) -> Result<ListMarker, ParseListMarkerError>
pub fn list_marker( &self, source: &str, ) -> Result<ListMarker, ParseListMarkerError>
Parse a list marker from string with this configuration.