pub struct FormatterBuilder { /* private fields */ }Expand description
Builder for the MarkdownFormatter
Implementations
Sourceimpl FormatterBuilder
impl FormatterBuilder
Sourcepub fn with_config(config: Config) -> Self
pub fn with_config(config: Config) -> Self
Create a FormatterBuilder with custom Config.
let builder = FormatterBuilder::with_config(Config {
max_width: Some(80),
..Default::default()
});
let formatter = builder.build();Sourcepub fn with_code_block_formatter<F>(formatter: F) -> Self
pub fn with_code_block_formatter<F>(formatter: F) -> Self
Create a FormatterBuilder with a custom code block formatter.
The closure used to reformat code blocks takes two arguments;
the info string and the complete code snippet
let builder = FormatterBuilder::with_code_block_formatter(|info_string, code_block| {
// Set the code block formatting logic
match info_string.to_lowercase().as_str() {
"rust" => {
// format rust code
}
_ => code_block,
}
});
let formatter = builder.build();Sourcepub fn build(self) -> MarkdownFormatter
pub fn build(self) -> MarkdownFormatter
Build a MarkdownFormatter
let builder = FormatterBuilder::default();
let formatter: MarkdownFormatter = builder.build();Sourcepub fn code_block_formatter<F>(&mut self, formatter: F) -> &mut Self
pub fn code_block_formatter<F>(&mut self, formatter: F) -> &mut Self
Configure how code blocks should be reformatted after creating the FormatterBuilder.
The closure passed to code_block_formatter takes two arguments;
the info string and the complete code snippet
Sourcepub fn max_width(&mut self, max_width: Option<usize>) -> &mut Self
pub fn max_width(&mut self, max_width: Option<usize>) -> &mut Self
Configure the max with when rewriting paragraphs.
When set to None, the deafault, paragraph width is left unchanged.
Sourcepub fn sichanghe_config(&mut self) -> &mut Self
pub fn sichanghe_config(&mut self) -> &mut Self
Set the configuration based on Steven Hé (Sīchàng)’s opinion.